# Requesting new Features

Given that we are currently at the beginning of the development of
the Bloqade python interface, we are open to suggestions about what
features would be helpful to include in future package iterations.
If you have a request for a new feature, please open an issue on our
GitHub page: https://github.com/QuEraComputing/bloqade-analog/issues

We ask that the feature requests be as specific as possible. Please
include the following information in your feature request:

1. A short, descriptive title.

2. A detailed description of the feature, including your attempt
to solve the problem with the current version of Bloqade.

3. A minimal code example that demonstrates the need for the feature.

4. The version of Bloqade you are using.

5. The version of Python you are using.

6. The version of your operating system.
